==> 1.1.0.tar.gz: lib/src/core/widgets/texts/texfields-listener/viewmodel.dart <==
part of modern_form_core;

class ModernFormTextFieldsListenerViewModel {
  final RxBool? validateEnabled;
  ModernFormTextFieldsListenerViewModel({this.validateEnabled});

  final _values = <ModernFormTextFieldListenner>[].obs;
  List<ModernFormTextFieldListenner> get values => this._values;
  set values(List<ModernFormTextFieldListenner> value) =>
      this._values.assignAll(value);

  List<TextEditingController> controllers = <TextEditingController>[];
  List<FocusNode> focus = <FocusNode>[];

  void init() {
    for (var i = 0; i < values.length; i++) {
      ModernFormTextFieldListenner value = values[i];
      setValue(value);
      setFocus();
      addListener(value, i);
    }
  }

  void restarting() {
    values.clear();
    controllers.clear();
    focus.clear();
    init();
  }

  void setValue(ModernFormTextFieldListenner value) {
    controllers.add(value.toController());
  }

  void setFocus() {
    focus.add(FocusNode());
  }

  void addListener(ModernFormTextFieldListenner value, int index) {
    if (value.onChange != null) {
      TextEditingController c = controllers[index];

      c.addListener(() {
        if (value.type == ModernFormTextFieldListennerType.Money ||
            value.type == ModernFormTextFieldListennerType.Number) {
          MoneyMaskedTextController c =
              controllers[index] as MoneyMaskedTextController;
          value.onChange!(c.numberValue);
        } else {
          value.onChange!(c.text);
        }
      });
    }
  }

  void dispose() {
    controllers.forEach((element) {
      element.dispose();
    });
    focus.forEach((element) {
      element.dispose();
    });

    controllers.clear();
    focus.clear();
  }

  static String? defaultValidator(dynamic value, String? fieldName) {
    if (value == null || value.toString().isEmpty) {
      return "Preencha o campo ${(fieldName ?? '').toLowerCase()}";
    }
    return null;
  }
}

extension TextFieldListennerExtension on ModernFormTextFieldListenner {
  ModernFormTextFieldListenner get withDefaultValidator {
    return this.copyWith(
      validator: (value) =>
          ModernFormTextFieldsListenerViewModel.defaultValidator(
        value,
        this.label,
      ),
    );
  }
}

==> 1.17.1.tar.gz: lib/src/core/widgets/texts/texfields-listener/viewmodel.dart <==
part of modern_form_core;

class ModernFormTextFieldsListenerViewModel {
  final RxBool? validateEnabled;
  ModernFormTextFieldsListenerViewModel({this.validateEnabled});

  final _values = <ModernFormTextFieldListenner>[].obs;
  List<ModernFormTextFieldListenner> get values => this._values;
  set values(List<ModernFormTextFieldListenner> value) =>
      this._values.assignAll(value);

  List<TextEditingController> controllers = <TextEditingController>[];
  List<FocusNode> focus = <FocusNode>[];

  void init() {
    for (var i = 0; i < values.length; i++) {
      ModernFormTextFieldListenner value = values[i];
      setValue(value);
      setFocus();
      addListener(value, i);
    }
  }

  void restarting() {
    values.clear();
    controllers.clear();
    focus.clear();
    init();
  }

  void setValue(ModernFormTextFieldListenner value) {
    controllers.add(value.toController());
  }

  void setFocus() {
    focus.add(FocusNode());
  }

  void addListener(ModernFormTextFieldListenner value, int index) {
    if (value.onChange != null) {
      TextEditingController c = controllers[index];

      c.addListener(() {
        if (value.type == ModernFormTextFieldListennerType.Money ||
            value.type == ModernFormTextFieldListennerType.Number) {
          MoneyMaskedTextController c =
              controllers[index] as MoneyMaskedTextController;
          value.onChange!(c.numberValue);
        } else {
          value.onChange!(c.text);
        }
      });
    }
  }

  void dispose() {
    controllers.forEach((element) {
      element.dispose();
    });
    focus.forEach((element) {
      element.dispose();
    });

    controllers.clear();
    focus.clear();
  }

  static String? defaultValidator(dynamic value, String? fieldName) {
    if (value == null || value.toString().isEmpty) {
      // return "Preencha o campo ${(fieldName ?? '').toLowerCase()}";
      return "O campo ${(fieldName ?? '').toLowerCase()} não pode estar vazio";
    }
    return null;
  }
}

extension TextFieldListennerExtension on ModernFormTextFieldListenner {
  ModernFormTextFieldListenner get withDefaultValidator {
    return this.copyWith(
      validator: (value) =>
          ModernFormTextFieldsListenerViewModel.defaultValidator(
        value,
        this.label,
      ),
    );
  }
}
